# Changelog

## v0.2.0 - Oct 12, 2022

- Added support for custom stylesheets

## v0.1.0 - Oct 11, 2022

- Initial release
- Added support for vis.js timeline
- Supported three parameters: `items`, `groups`, `options`
